.. include:: ../README.rst

Narrative documentation
-----------------------

.. toctree::
   :maxdepth: 2

   changes

API documentation
-----------------

.. toctree::
   :maxdepth: 2

   api/tools
   api/content

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
